@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
@@ -16,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-deletable-bucket",
-    "1.0.26",
+    "1.0.27",
     __name__[0:-6],
-    "cdk-deletable-bucket@1.0.26.jsii.tgz",
+    "cdk-deletable-bucket@1.0.27.jsii.tgz",
 )
 
 __all__ = [
